@@ -3,7 +3,7 @@
  * WP Multibyte Patch Japanese Locale Extension
  *
  * @package WP_Multibyte_Patch
- * @version 2.3.1
+ * @version 2.4
  * @author Seisuke Kuraishi <210pura@gmail.com>
  * @copyright Copyright (c) 2015 Seisuke Kuraishi, Tinybit Inc.
  * @license http://opensource.org/licenses/gpl-2.0.php GPLv2
@@ -150,11 +150,14 @@ if ( class_exists( 'multibyte_patch' ) ) :
 	}
 
 	function wp_trim_words( $text = '', $num_words = 110, $more = '', $original_text = '' ) {
-		if ( 'characters' != _x( 'words', 'word count: words or characters?' ) )
+		if (
+			$this->is_wp_required_version( '4.3-RC1' ) && 0 !== strpos( _x( 'words', 'Word count type. Do not translate!' ), 'characters' ) || 
+			!$this->is_wp_required_version( '4.3-RC1' ) && 'characters' != _x( 'words', 'word count: words or characters?' )
+		)
 			return $text;
 
 		// If the caller is wp_dashboard_recent_drafts()
-		if( false !== $this->conf['patch_dashboard_recent_drafts'] && 10 === $num_words && is_admin() && strpos( wp_debug_backtrace_summary(), 'wp_dashboard_recent_drafts' ) )
+		if ( false !== $this->conf['patch_dashboard_recent_drafts'] && 10 === $num_words && is_admin() && strpos( wp_debug_backtrace_summary(), 'wp_dashboard_recent_drafts' ) )
 			$num_words = $this->conf['dashboard_recent_drafts_mblength'];
 
 		$text = $original_text;
